summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t3.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials/t3.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t3.cs12
1 files changed, 6 insertions, 6 deletions
diff --git a/qtsharp/src/examples/tutorials/t3.cs b/qtsharp/src/examples/tutorials/t3.cs
index 806c5184..26fece72 100644
--- a/qtsharp/src/examples/tutorials/t3.cs
+++ b/qtsharp/src/examples/tutorials/t3.cs
@@ -10,16 +10,16 @@ public class Example {
public static int Main (String[] args)
{
- TTQApplication a = new TTQApplication (args);
+ TQApplication a = new TQApplication (args);
- TTQVBox box = new TTQVBox ();
+ TQVBox box = new TQVBox ();
box.Resize (200, 120);
- TTQPushButton quit = new TTQPushButton ("Quit", box);
- quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold));
- // In C++, TTQFont::Bold is sufficient
+ TQPushButton quit = new TQPushButton ("Quit", box);
+ quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
+ // In C++, TQFont::Bold is sufficient
- TTQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
// TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (box);